# L-System Project
## Software Engineering I  | Math and Computer Science Department

### Project Description
This application is made in Python. The goal of this application is to be able to easily visualize L-Systems, so that researchers can spend more time on the theory. Currently we are in version 0.01, which has basic capabilities of accepting user input and displaying the L-System. This project is Team BRAWTs senior capstone project for Software Engineering. Our client is Micahel Bardzell, PhD.

### Future Release
Version 0.02 will include the ability to create multiple production rules
Have basic L-Systems for user to visualize
Better graphics 

### Running the Application
Clone the repository, then run the following line of code in the main directory:

```pip install -r requirements.txt```

```python run.py```

### Contributers
- Chris Arausa @wrathofrathma
- Lela Bones @lelatbones
- Matt Rovine @battblairro
- Matt Tibebe @mattythats
- Stephanie Warman @swarman2


